==> plasma-workspace-5.12.4.tar.xz: plasma-workspace-5.12.4/dataengines/share/packagestructure/share_package.h <==
/***************************************************************************
 *   Copyright 2010 Artur Duque de Souza <asouza@kde.org>                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#ifndef SHARE_PACKAGE_H
#define SHARE_PACKAGE_H

#include <kpackage/packagestructure.h>

class SharePackage : public KPackage::PackageStructure
{
public:
    SharePackage(QObject *parent = 0, QVariantList args = QVariantList());
    void initPackage(KPackage::Package *package) override;
};

#endif

==> plasma-workspace-5.14.3.tar.xz: plasma-workspace-5.14.3/dataengines/share/packagestructure/share_package.h <==
/***************************************************************************
 *   Copyright 2010 Artur Duque de Souza <asouza@kde.org>                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#ifndef SHARE_PACKAGE_H
#define SHARE_PACKAGE_H

#include <kpackage/packagestructure.h>

class SharePackage : public KPackage::PackageStructure
{
public:
    explicit SharePackage(QObject *parent = nullptr, QVariantList args = QVariantList());
    void initPackage(KPackage::Package *package) override;
};

#endif
